@@ -107,7 +107,7 @@ class CrowdTangle:
                     if not data['result']['posts']:
                         print(f"Empty response on url: {url}")
                         logger.debug(f"Empty response on url: {url}")
-                        time.sleep(30)
+                        time.sleep(sleep_time)
                         continue
 
                     # convert json response to dataframe
@@ -156,7 +156,7 @@ class CrowdTangle:
                     del df
                     del df_full
 
-                except:
+                except Exception as e:
                     logger.exception(f"error on {url}")
                     print(f"error on {url}")
                 # wait time
